import requests
import json

def get_information(data, product, verify_ssl):
    js = json.dumps(data, ensure_ascii=False)
    url = 'https://service.zipcode.com.br/api/'+product

    # call get service with headers and params
    response = requests.post(url, data=js, headers={"Content-Type": "application/json"},verify=verify_ssl)
    ret = response.json()
    return ret





import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='tu_connect',
    version='1.0.0',
    author='Rogerio Domingues',
    author_email='rogerio.domingues@transunion.com',
    description=u'Connection to TU API BRZ',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://service.zipcode.com.br/api/help',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)